@@ -330,7 +330,7 @@ sub update {
 	$sku = shift @args;
 	$qty = shift @args;
 
-	unless ($item = $self->_find($sku)) {
+	unless ($item = $self->find($sku)) {
 	    die "Item for $sku not found in cart.\n";
 	}
 
@@ -386,6 +386,29 @@ sub clear {
     return;
 }
 
+=head2 find
+
+Searches for an cart item with the given SKU.
+Returns cart item in case of sucess.
+
+    if ($item = $cart->find(9780977920174)) {
+        print "Quantity: $item->{quantity}.\n";
+    }
+
+=cut
+
+sub find {
+    my ($self, $sku) = @_;
+
+    for my $cartitem (@{$self->{items}}) {
+	if ($sku eq $cartitem->{sku}) {
+	    return $cartitem;
+        }
+    }
+
+    return;
+}
+
 =head2 quantity
 
 Returns the sum of the quantity of all items in the shopping cart,
@@ -589,18 +612,6 @@ sub seed {
     return $self->{items};
 }
 
-sub _find {
-    my ($self, $sku) = @_;
-
-    for my $cartitem (@{$self->{items}}) {
-	if ($sku eq $cartitem->{sku}) {
-	    return $cartitem;
-        }
-    }
-
-    return;
-}
-
 sub _combine {
     my ($self, $item) = @_;
 
